@@ -144,12 +144,15 @@ class TestBase:
         if not user_uuid:
             user_uuid = str(uuid4())
 
-        event_service = EventService(
-            correlation_id=str(uuid4()),
-            domain="domain",
-            context="context",
-            user_uuid=user_uuid,
-        )
+        if instance_type == "command":
+            event_service = EventService(
+                correlation_id=str(uuid4()),
+                domain="domain",
+                context="context",
+                user_uuid=user_uuid,
+            )
+        else:
+            event_service = None
 
         infra = InfraFactoryMock(infra=mocked_infra)
         repo_factory = MockRepositoryFactory(infra_factory=infra)
