@@ -47,11 +47,14 @@ class Repository(RepositoryBase):
         for ev in self.event_service.get_events_by_type(
             entity_type=self._for_entity
         ):
-            method_to_call = getattr(
-                self, self._events_to_calls[ev.event_name]
-            )
+            if not ev.processed:
+                method_to_call = getattr(
+                    self, self._events_to_calls[ev.event_name]
+                )
 
-            method_to_call(ev, user_info, dry_run)
+                method_to_call(ev, user_info, dry_run)
+            if not dry_run:
+                ev.processed = True
 
 
 class RepositoryFactory(Base):
